@@ -1,10 +1,10 @@
-__version__ = "0.2.1"
+__version__ = "0.2.2"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.2.1)'
+__git_branch__ = '(detached from v0.2.2)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '98064557513d81ba5650451b0ff21d55d1c24c16'
-__git_head_subject__ = 'Finished release v0.2.1.'
+__git_head_hash__ = '45b51841a0d23ea3e4121e00d2f5262ad240abe0'
+__git_head_subject__ = 'buildout.cfg: changed isolated python version to v2.7.6.6'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
